@@ -23,29 +23,29 @@ my %dispatcher = (
     'PPI::Token::Symbol'      => \&_variable_is_camelcase,
 );
 
-sub applies_to { 
+sub applies_to {
     keys %dispatcher,
 }
 
 sub violates {
     my ( $self, $elem ) = @_;
-    
+
     my $ref = ref $elem;
     my $sub = $dispatcher{$ref};
     return if !$sub;
-    
+
     my $success = $self->$sub( $elem );
-    
+
     return if $success;
     return $self->violation( $DESC, $EXPL, $elem );
 }
 
 sub _is_camelcase {
     my ( $self, $elem ) = @_;
-    
+
     my $words = $elem->find( 'PPI::Token::Word' );
     my $name  = $words->[1];
-    
+
     if ( $elem->isa( 'PPI::Statement::Sub' ) and $name eq 'new' ) {
         return 1;
     }
@@ -55,25 +55,39 @@ sub _is_camelcase {
     elsif ( $elem->isa( 'PPI::Statement::Package' ) and $name =~ m{ Language :: [a-z]{2,3}_ }xms ) {
         return 1;
     }
-    
+
     return 1 if !$name;
-    
-    my $is_camelcase = !( $name !~ m{ \A [A-Z][a-z]* }xms || $name =~ m{ _ }xms );
-    
+
+    my $is_camelcase = !( $name !~ m{ \A _* [A-Z][a-z]* }xms || $name =~ m{ [^_]_ }xms );
+
     return $is_camelcase;
 }
 
 sub _variable_is_camelcase {
     my ( $self, $elem ) = @_;
-    
+
     my $name = "$elem";
-    
-    my $is_camelcase = !( $name !~ m{ \A [\*\@\$\%][A-Z][a-z]* }xms || $name =~ m{ _ }xms );
-    
+
+    # Allow Perl builtins.
+    return 1 if $name eq '$a';
+    return 1 if $name eq '$b';
+
+    # Ignore function calls
+    return 1 if substr($name, 0, 1) eq '&';
+
+    # Allow short variable names with lowercase characters like $s.
+    return 1 if length $name == 2;
+
+    my $is_camelcase = !( $name !~ m{ \A [\*\@\$\%]_*[A-Z][a-z]* }xms || $name =~ m{ [^_]_ }xms );
+
+    #print STDERR "$name" if !$is_camelcase;
+
     return $is_camelcase;
 }
 
 1;
+
+
 __END__
 =pod
 
@@ -83,7 +97,7 @@ Perl::Critic::Policy::OTRS::RequireCamelCase
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 AUTHOR
 
@@ -91,7 +105,7 @@ Renee Baecker <module@renee-baecker.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2010 by Renee Baecker.
+This software is Copyright (c) 2013 by Renee Baecker.
 
 This is free software, licensed under:
 
