@@ -20,19 +20,25 @@ sub applies_to           { return 'PPI::Token::Operator' }
 
 sub violates {
     my ( $self, $elem ) = @_;
-    
+
     return if $elem ne '->';
-    
+
     my $method = $elem->snext_sibling;
+
+    # $Variable->();
+    return if ref $method eq 'PPI::Structure::List';
+
+    # $Variable->method();
     return if ref $method eq 'PPI::Structure::Subscript';
-    
+
     my $list   = $method->snext_sibling;
     return if ref $list eq 'PPI::Structure::List';
-    
+
     return $self->violation( $DESC, $EXPL, $elem );
 }
 
 1;
+
 __END__
 =pod
 
@@ -42,7 +48,7 @@ Perl::Critic::Policy::OTRS::RequireParensWithMethods
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 AUTHOR
 
@@ -50,7 +56,7 @@ Renee Baecker <module@renee-baecker.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2010 by Renee Baecker.
+This software is Copyright (c) 2013 by Renee Baecker.
 
 This is free software, licensed under:
 
